package agentkindboxhandler

import (
	"net/http"

	param "git.gocasts.ir/ebhomengo/niki/param/agent/kind_box"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	"github.com/labstack/echo/v4"
)

// Get godoc
// @Summary      Get a kind box that is awaiting return by agent
// @Tags         Agents KindBoxes
// @Accept       json
// @Produce      json
// @Param        id path int true "KindBox ID"
// @Success      200  {object}  param.GetKindBoxResponse
// @Failure      400  {string}  "Bad Request"
// @Failure      401  {string}  "invalid or expired jwt"
// @Failure      403  {string}  "user not allowed"
// @Failure      422  {object}  httpmsg.ErrorResponse
// @Failure      500  {string}  "something went wrong"
// @Security 	 AuthBearerAdmin
// @Router       /agents/kindboxes/{id} [get].
func (h Handler) Get(c echo.Context) error {
	var req param.GetKindBoxRequest
	if bErr := c.Bind(&req); bErr != nil {
		return echo.NewHTTPError(http.StatusBadRequest)
	}

	claims := claim.GetClaimsFromEchoContext(c)
	req.AgentID = claims.UserID

	resp, sErr := h.agentKindBoxSvc.Get(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)
		if resp.FieldErrors != nil {
			return c.JSON(code, httpmsg.ErrorResponse{
				Message: msg,
				Errors:  resp.FieldErrors,
			})
		}

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusOK, resp)
}
