package agentkindboxhandler

import (
	"net/http"

	params "git.gocasts.ir/ebhomengo/niki/param"
	param "git.gocasts.ir/ebhomengo/niki/param/agent/kind_box"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	echo "github.com/labstack/echo/v4"
)

// Return godoc
// @Summary      Return KindBox from benefactor by agent
// @Tags         Agents KindBoxes
// @Accept       json
// @Produce      json
// @Param 		 id path int true "KindBox ID"
// @Param		 Request body param.ReturnKindBoxRequest true "Return KindBox Request Body"
// @Success      204
// @Failure      400  {string}  "Bad Request"
// @Failure      401  {string}  "invalid or expired jwt"
// @Failure      403  {string}  "user not allowed"
// @Failure      422  {object}  httpmsg.ErrorResponse
// @Failure      500  {string}  "something went wrong"
// @Security 	 AuthBearerAdmin
// @Router       /agents/kindboxes/{id}/return [patch].
func (h Handler) Return(c echo.Context) error {
	var req param.ReturnKindBoxRequest
	if err := c.Bind(&req); err != nil {
		return echo.NewHTTPError(http.StatusBadRequest)
	}

	claims := claim.GetClaimsFromEchoContext(c)
	req.AgentID = claims.UserID

	resp, sErr := h.agentKindBoxSvc.Return(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)
		if resp.FieldErrors != nil {
			return c.JSON(code, httpmsg.ErrorResponse{
				Message: msg,
				Errors:  resp.FieldErrors,
			})
		}

		return echo.NewHTTPError(code, msg)
	}

	go h.notificationSvc.KindBoxReturned(params.NotificationKindBoxReturned{
		KindBoxID: req.KindBoxID,
	})

	return c.NoContent(http.StatusNoContent)
}
